@@ -14,21 +14,34 @@ class StandardSize(ValueBased, Enum):
     MM_15_X_45 = (158, 9)
     MM_20_X_40 = (156, 9)
     MM_20_X_50 = (161, 9)
+    MM_21_X_51 = (234, 9)
     MM_21_X_68 = (169, 8)
     MM_25_X_50 = (162, 9)
+    MM_25_X_51 = (249, 9)
     MM_30_X_70 = (192, 8)
+    MM_33_X_62 = (241, 9)
     MM_35_X_105 = (153, 7)
     MM_35_X_210 = (154, 5)
     MM_35_X_316 = (155, 4)
+    MM_37_X_50 = (238, 9)
     MM_40_X_50 = (163, 8)
+    MM_45_X_96 = (236, 7)
     MM_48_X_70 = (160, 8)
+    MM_49_X_60 = (237, 9)
+    MM_51_X_76 = (240, 8)
     MM_51_X_298 = (165, 4)
     MM_51_X_420 = (166, 3)
     MM_52_X_210 = (209, 5)
     MM_55_X_85 = (167, 8)
     MM_55_X_148 = (207, 6)
     MM_55_X_173 = (208, 6)
+    MM_63_X_88 = (249, 7)
+    MM_68_X_96 = (243, 7)
+    MM_70_X_90 = (244, 7)
     MM_71_X_96 = (171, 7)
+    MM_75_X_110 = (245, 6)
+    MM_90_X_136 = (247, 6)
+    MM_94_X_140 = (248, 6)
     MM_95_X_145 = (175, 6)
     MM_95_X_45 = (173, 7)
     MM_95_X_210 = (231, 5)
@@ -178,13 +191,17 @@ class StandardSize(ValueBased, Enum):
     SQUARE_25_MM = (148, 9)
     SQUARE_30_MM = (150, 9)
     SQUARE_35_MM = (152, 9)
+    SQUARE_37_MM = (235, 9)
     SQUARE_40_MM = (157, 9)
     SQUARE_45_MM = (159, 8)
     SQUARE_50_MM = (164, 8)
+    SQUARE_51_MM = (239, 9)
     SQUARE_55_MM = (32, 8)
     SQUARE_60_MM = (168, 8)
+    SQUARE_64_MM = (242, 8)
     SQUARE_70_MM = (170, 7)
     SQUARE_80_MM = (172, 7)
+    SQUARE_88_MM = (246, 7)
     SQUARE_95_MM = (174, 6)
     SQUARE_98_MM = (35, 6)
     SQUARE_100_MM = (21, 6)
@@ -212,6 +229,13 @@ class StandardSize(ValueBased, Enum):
     ENVELOPE_C4 = (25, 3)
     ENVELOPE_DL = (23, 4)
 
+    # SRA Sizes
+    SRA0 = (251, 0)
+    SRA1 = (252, 1)
+    SRA2 = (253, 2)
+    SRA3 = (254, 3)
+    SRA4 = (255, 4)
+
     # Miscellaneous Sizes
     A1_LONG = (14, 0)
     A2_LONG = (15, 1)
