@@ -4,12 +4,17 @@ from typing import Protocol, runtime_checkable, Tuple, Any, TYPE_CHECKING
 
 from pydantic import BaseModel
 
-from mixam_sdk.item_specification import enums as Enums
-
 if TYPE_CHECKING:
     from mixam_sdk.item_specification.models import Embellishments, CustomSize
     from mixam_sdk.item_specification.models.foiling import Foiling
     from mixam_sdk.item_specification.models.substrate import Substrate
+    from mixam_sdk.item_specification.enums.shape import Shape
+    from mixam_sdk.item_specification.enums.component_type import ComponentType
+    from mixam_sdk.item_specification.enums.standard_size import StandardSize
+    from mixam_sdk.item_specification.enums.orientation import Orientation
+    from mixam_sdk.item_specification.enums.colours import Colours
+    from mixam_sdk.item_specification.enums.pre_drilled_holes import PreDrilledHoles
+    from mixam_sdk.item_specification.enums.lamination import Lamination
 
 class Member(BaseModel):
     code: str
@@ -26,13 +31,13 @@ def container_meta(code: str) -> dict[str, Container]:
 @runtime_checkable
 class Component(Protocol):
     format: int
-    component_type: Enums.CompononetType | None
-    standard_size: Enums.StandardSize
+    component_type: ComponentType
+    standard_size: StandardSize
     custom_size: CustomSize | None
-    orientation: Enums.Orientation
+    orientation: Orientation
     substrate: Substrate
-    colours: Enums.Colours
-    pre_drilled_holes: Enums.PreDrilledHoles
+    colours: Colours
+    pre_drilled_holes: PreDrilledHoles
     embellishments: Embellishments
 
     def has_back(self) -> bool: ...
@@ -41,10 +46,11 @@ class Component(Protocol):
     def is_laminated_component(self) -> bool: ...
     def is_two_sided_component(self) -> bool: ...
     def is_foiled_component(self) -> bool: ...
+    def is_shaped_component(self) -> bool: ...
 
 @runtime_checkable
 class LaminatedComponent(Component, Protocol):
-    lamination: Enums.Lamination
+    lamination: Lamination
 
 @runtime_checkable
 class FoiledComponent(Component, Protocol):
@@ -52,10 +58,14 @@ class FoiledComponent(Component, Protocol):
 
 @runtime_checkable
 class TwoSidedComponent(LaminatedComponent, FoiledComponent, Protocol):
-    back_colours: Enums.Colours
-    back_lamination: Enums.Lamination
+    back_colours: Colours
+    back_lamination: Lamination
     back_foiling: Foiling
 
+@runtime_checkable
+class ShapedComponent(Component, Protocol):
+    shape: Shape
+
 SUBSTRATE_COMPARISON_FORMAT = "%s|%s|%s"
 
 def _enum_key(x: Any) -> str:
