@@ -10,7 +10,7 @@ from mixam_sdk.item_specification.interfaces.component_protocol import member_me
 from mixam_sdk.item_specification.models.two_sided_component_support import (
     TwoSidedComponentSupport,
 )
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class CoverComponent(TwoSidedComponentSupport):
@@ -21,10 +21,12 @@ class CoverComponent(TwoSidedComponentSupport):
 
     component_type: Literal[ComponentType.COVER] = Field(
         default=ComponentType.COVER,
+        alias="componentType",
+        validation_alias="componentType",
         frozen=True
     )
 
-    cover_area: Annotated[CoverArea, enum_by_name(CoverArea), enum_dump_name] = Field(
+    cover_area: Annotated[CoverArea, enum_by_name_or_value(CoverArea), enum_dump_name] = Field(
         default=CoverArea.FRONT_AND_BACK,
         alias="coverArea",
         description="The area of the cover component.",
