@@ -7,7 +7,7 @@ from pydantic import Field, ConfigDict
 from mixam_sdk.item_specification.enums.lamination import Lamination
 from mixam_sdk.item_specification.interfaces.component_protocol import member_meta
 from mixam_sdk.item_specification.models.component_support import ComponentSupport
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class LaminatedComponentSupport(ComponentSupport):
@@ -16,7 +16,7 @@ class LaminatedComponentSupport(ComponentSupport):
         "lamination": "l",
     }
 
-    lamination: Annotated[Lamination, enum_by_name(Lamination), enum_dump_name] = Field(
+    lamination: Annotated[Lamination, enum_by_name_or_value(Lamination), enum_dump_name] = Field(
         default=Lamination.NONE,
         description="Type of lamination applied to the component.",
         json_schema_extra=member_meta(FIELDS["lamination"]),
