@@ -17,6 +17,8 @@ class ShrinkWrapComponent(ComponentSupport):
 
     component_type: Literal[ComponentType.SHRINK_WRAP] = Field(
         default=ComponentType.SHRINK_WRAP,
+        alias="componentType",
+        validation_alias="componentType",
         frozen=True
     )
 
