@@ -6,7 +6,7 @@ from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.substrate_design import SubstrateDesign
 from mixam_sdk.item_specification.interfaces.component_protocol import member_meta
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class Substrate(BaseModel):
@@ -36,7 +36,7 @@ class Substrate(BaseModel):
         json_schema_extra=member_meta(FIELDS["colourId"]),
     )
 
-    design: Annotated[SubstrateDesign, enum_by_name(SubstrateDesign), enum_dump_name] = Field(
+    design: Annotated[SubstrateDesign, enum_by_name_or_value(SubstrateDesign), enum_dump_name] = Field(
         default=SubstrateDesign.NONE,
         json_schema_extra=member_meta(FIELDS["design"]),
     )
