@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.binding_edge import BindingEdge
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class BindingEdgeMetadata(BaseModel):
 
-    binding_edge: Annotated[BindingEdge, enum_by_name(BindingEdge), enum_dump_name] = Field(
+    binding_edge: Annotated[BindingEdge, enum_by_name_or_value(BindingEdge), enum_dump_name] = Field(
         alias="bindingEdge",
     )
 
