@@ -5,7 +5,7 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.colours import Colours
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class ColoursOption(BaseModel):
@@ -14,7 +14,7 @@ class ColoursOption(BaseModel):
         default="",
     )
 
-    colours: Annotated[Colours, enum_by_name(Colours), enum_dump_name] = Field(
+    colours: Annotated[Colours, enum_by_name_or_value(Colours), enum_dump_name] = Field(
         default=Colours.NONE,
     )
 
