@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.end_paper_colour import EndPaperColour
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class EndPaperMetadata(BaseModel):
 
-    end_paper_colour: Annotated[EndPaperColour, enum_by_name(EndPaperColour), enum_dump_name] = Field(
+    end_paper_colour: Annotated[EndPaperColour, enum_by_name_or_value(EndPaperColour), enum_dump_name] = Field(
         alias="endPaperColour",
     )
 
