@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.flap_width import FlapWidth
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class FlapWidthOption(BaseModel):
 
-    flap_width: Annotated[FlapWidth, enum_by_name(FlapWidth), enum_dump_name] = Field(
+    flap_width: Annotated[FlapWidth, enum_by_name_or_value(FlapWidth), enum_dump_name] = Field(
         alias="flapWidth",
     )
 
