@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.frame_depth import FrameDepth
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class FrameDepthOption(BaseModel):
 
-    frame_depth: Annotated[FrameDepth, enum_by_name(FrameDepth), enum_dump_name] = Field(
+    frame_depth: Annotated[FrameDepth, enum_by_name_or_value(FrameDepth), enum_dump_name] = Field(
         alias="frameDepth",
     )
 
