@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.pre_drilled_holes import PreDrilledHoles
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class PreDrilledHoleOption(BaseModel):
 
-    pre_drilled_holes: Annotated[PreDrilledHoles, enum_by_name(PreDrilledHoles), enum_dump_name] = Field(
+    pre_drilled_holes: Annotated[PreDrilledHoles, enum_by_name_or_value(PreDrilledHoles), enum_dump_name] = Field(
         alias="preDrilledHoles",
     )
 
