@@ -6,14 +6,14 @@ from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.substrate_type import SubstrateType
 from mixam_sdk.metadata.product.models import Capacity
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class ShrinkWrapOption(BaseModel):
 
     label: str = Field()
 
-    substrate_type: Optional[Annotated[SubstrateType, enum_by_name(SubstrateType), enum_dump_name]] = Field(
+    substrate_type: Optional[Annotated[SubstrateType, enum_by_name_or_value(SubstrateType), enum_dump_name]] = Field(
         default=None,
         alias="substrateType",
     )
