@@ -6,12 +6,12 @@ from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.simple_fold import SimpleFold
 from mixam_sdk.metadata.product.enums.trilean import Trilean
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class SimpleFoldOption(BaseModel):
 
-    simple_fold: Annotated[SimpleFold, enum_by_name(SimpleFold), enum_dump_name] = Field(
+    simple_fold: Annotated[SimpleFold, enum_by_name_or_value(SimpleFold), enum_dump_name] = Field(
         alias="simpleFold",
     )
 
@@ -24,7 +24,7 @@ class SimpleFoldOption(BaseModel):
         alias="availableSides",
     )
 
-    delivered_flat: Annotated[Trilean, enum_by_name(Trilean), enum_dump_name] = Field(
+    delivered_flat: Annotated[Trilean, enum_by_name_or_value(Trilean), enum_dump_name] = Field(
         alias="deliveredFlat",
     )
 
