@@ -5,12 +5,12 @@ from typing import Annotated
 from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.substrate_design import SubstrateDesign
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class SubstrateDesignMetadata(BaseModel):
 
-    substrate_design: Annotated[SubstrateDesign, enum_by_name(SubstrateDesign), enum_dump_name] = Field(
+    substrate_design: Annotated[SubstrateDesign, enum_by_name_or_value(SubstrateDesign), enum_dump_name] = Field(
         alias="substrateDesign",
     )
 
