@@ -6,7 +6,7 @@ from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.item_specification.enums.substrate_group import SubstrateGroup
 from mixam_sdk.item_specification.enums.substrate_type import SubstrateType
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 from .substrate_colour_metadata import SubstrateColourMetadata
 
 
@@ -14,11 +14,11 @@ class SubstrateTypeMetadata(BaseModel):
 
     id: int = Field()
 
-    substrate_type: Annotated[SubstrateType, enum_by_name(SubstrateType), enum_dump_name] = Field(
+    substrate_type: Annotated[SubstrateType, enum_by_name_or_value(SubstrateType), enum_dump_name] = Field(
         alias="substrateType",
     )
 
-    substrate_group: Annotated[SubstrateGroup, enum_by_name(SubstrateGroup), enum_dump_name] = Field(
+    substrate_group: Annotated[SubstrateGroup, enum_by_name_or_value(SubstrateGroup), enum_dump_name] = Field(
         alias="substrateGroup",
     )
 
