@@ -6,7 +6,7 @@ from pydantic import BaseModel, Field, ConfigDict
 
 from mixam_sdk.metadata.product.enums.weight_unit import WeightUnit
 from mixam_sdk.metadata.product.models import PageCountMetadata
-from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
+from mixam_sdk.utils.enum_json import enum_by_name_or_value, enum_dump_name
 
 
 class SubstrateWeightMetadata(BaseModel):
@@ -19,7 +19,7 @@ class SubstrateWeightMetadata(BaseModel):
 
     caliper: float = Field()
 
-    unit: Annotated[WeightUnit, enum_by_name(WeightUnit), enum_dump_name] = Field()
+    unit: Annotated[WeightUnit, enum_by_name_or_value(WeightUnit), enum_dump_name] = Field()
 
     label: str = Field()
 
